PCB Environment: Data Fields - Functions

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all functions with links to the structures/unions they belong to:

### - i -

- i() : Parameter
- IBox_3() : IBox_3
- id() : Connection, Net, Object
- ignoreLayoutBounds() : PCBFactory
- inCompound() : Pin
- incRef() : py::Object
- incSearchSeq() : NavTriangulation
- indent() : Logger
- index() : Action, IPoint_3
- indexCountWithRestart() : AShape, PolygonEx
- IndexRange() : IndexRange
- inferEnd() : Track
- inferEndpoints() : Track
- inferEndsWithVia() : Track
- inferMissingNetWidths() : dsn::Data
- inferStart() : Track
- inferStartsWithVia() : Track
- Info() : Logger
- init() : ActionSet, ActionTab, BrowserTab, Parameter, ParameterTab, StateRepresentation, ViewTab
- initialized() : NavSpacings
- initializeGL() : GLWidget
- initParameters() : Agent
- initPathfindingFor() : PCBoard
- initPathfindingForNet() : PCBoard
- initSpacingsForAnyRoutedTrack() : NavGrid
- insert() : ActionSet, Net, ObjectsBVH
- insertRoute() : NavTriangulation
- inside() : UniformGrid25
- insidePin() : NavPoint
- install() : SignalContext
- Int64() : Token
- interrupt() : UIActions
- intersects() : AShape, CircleEx, Connection, IsoRectEx, Object, Path, PolygonEx, Track, TriangleEx, WideSegment_25
- IPoint_2() : IPoint_2
- IPoint_3() : IPoint_3
- is2D() : GridDirection
- is_a() : Object, Parameter
- is_horizontal() : Segment_25
- is_vertical() : Segment_25
- isBboxInside() : LayoutArea
- isBool() : py::Object
- isBracket() : DSNParserBase
- isContainerOf() : Object
- isContiguous() : Track
- isDiagonal() : GridDirection
- isDict() : py::Object
- isDone() : AStarVisitStatus
- isFloat() : py::Object
- isGround() : Layer, Net
- isGroundOrPower() : Net
- isInside() : LayoutArea
- isInsideBbox() : Object
- isList() : py::Object
- isLocked() : Connection
- isLong() : py::Object
- isLongVector() : py::Object
- isNone() : py::Object
- isNonzero() : NavPixel< chan_t >
- isNoop() : NavRasterizeParams
- isNumber() : py::Object
- isOnLayer() : Object
- isOpen() : AStarVisitStatus
- isOrderedXMajor() : Connection
- IsoRectEx() : IsoRectEx
- isOwner() : LogFile
- isPacked() : py::NPArray< T >
- isPlaced() : Component
- isPlanarAt() : Path
- isPoint_25() : py::Object
- isPositive() : IPoint_2, IPoint_3
- isPower() : Layer
- isPreviewing() : UIActions
- isPreviewReady() : UIActions
- isPreviewStale() : UIActions
- isPreviewTrackLegal() : UIActions
- isRasterized() : Track
- isRasterized_allOrNone() : Connection
- isRatsNestLimited() : GLWidget
- isRatsNestShown() : GLWidget
- isRound() : AShape, CircleEx, WideSegment_25
- isRouted() : Connection
- isSeen() : AStarVisitStatus
- isSelected() : Object
- isSet() : RouterResult
- isSignal() : Layer
- isString() : py::Object
- isTriangulationShown() : GLWidget
- isTuple() : py::Object
- isTupleOrList() : py::Object
- isVector() : py::Object
- isVertical() : GridDirection
- isVisible() : Camera, Color
- isXOrdered() : Segment_25
- isYOrdered() : Segment_25
- isZero() : GridDirection, NavKeepoutCounts
- item() : py::Object
- ivec3() : GridDirection
- IVector_2() : IVector_2
- IVector_3() : IVector_3